# isoPy

[![PyPI version](https://badge.fury.io/py/isopy.svg)](https://badge.fury.io/py/isopy)
[![Build Status](https://travis-ci.com/mattias-ek/isopy.svg?branch=master)](https://travis-ci.com/mattias-ek/isopy)
[![codecov](https://codecov.io/gh/mattias-ek/isopy/branch/master/graph/badge.svg?token=W6SII47DJI)](https://codecov.io/gh/mattias-ek/isopy)

Isopy is a Python 3 library for data processing in isotope geo/cosmochemistry.

## Installation

```bash
pip install isopy
```

**Note** Isopy requires python 3.8 and above.

For more information on installing isopy see Installing isopy documentation.

## License
[MIT]()

